/**
 * Copyright 2017-2018 ZTE Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onap.sdc.workflowdesigner.externalservice.sdc;

import org.glassfish.jersey.client.ClientConfig;
import org.onap.sdc.workflowdesigner.common.SDCProxyException;
import org.onap.sdc.workflowdesigner.config.AppConfig;
import org.onap.sdc.workflowdesigner.externalservice.sdc.entity.WorkflowArtifactInfo;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.eclipsesource.jaxrs.consumer.ConsumerFactory;

/**
 * 
 */
public class SDCServiceProxy {
  private static final Logger LOGGER = LoggerFactory.getLogger(SDCService.class);

  private static final String AUTHORIZATION = AppConfig.getSdcServiceProxy().getAuthorization();

  private static final String X_ECOMP_INSTANCE_ID =
      AppConfig.getSdcServiceProxy().getxEcompInstanceId();
  /** */
  private static final String SDC_ROOT_PATH = "/sdc/v1";


  private static String getSDCRootPath() {
    return AppConfig.getSdcServiceProxy().getServiceAddr() + SDC_ROOT_PATH;
  }

  /**
   * @return
   */
  private SDCService getSDCServiceProxy() {
    ClientConfig config = new ClientConfig();
    return ConsumerFactory.createConsumer(getSDCRootPath(), config, SDCService.class);
  }

  /**
   * 
   * @param uuid
   * @param operationId
   * @param workflowId
   * @param workflowArtifactInfo
   * @throws SDCProxyException
   */
  public void saveWorkflowArtifact(String uuid, String operationId, String workflowId,
      WorkflowArtifactInfo workflowArtifactInfo) throws SDCProxyException {
    SDCService serviceProxy = getSDCServiceProxy();
    try {
      serviceProxy.saveWorkflowArtifact(uuid, operationId, workflowId, X_ECOMP_INSTANCE_ID,
          AUTHORIZATION, workflowArtifactInfo);
    } catch (Exception e) {
      LOGGER.error("Save WorkflowArtifact Failed.", e);
      throw new SDCProxyException("Save WorkflowArtifact Failed.", e);
    }
  }

  /**
   * 
   * @param uuid
   * @param operationId
   * @param workflowId
   * @return
   * @throws SDCProxyException
   */
  public WorkflowArtifactInfo getWorkflowArtifact(String uuid, String operationId,
      String workflowId) throws SDCProxyException {
    SDCService serviceProxy = getSDCServiceProxy();
    try {
      return serviceProxy.getWorkflowArtifact(uuid, operationId, workflowId, X_ECOMP_INSTANCE_ID,
          AUTHORIZATION);
    } catch (Exception e) {
      LOGGER.error("Get WorkflowArtifact Failed.", e);
      throw new SDCProxyException("Get WorkflowArtifact Failed.", e);
    }
  }


}
